summaryrefslogtreecommitdiffstats
path: root/src/include/runtime/interface.h
diff options
context:
space:
mode:
authorDoug Gilbert <dgilbert@us.ibm.com>2014-04-18 12:12:39 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2014-04-25 15:48:08 -0500
commit90ba110f5fda85e77cee73d8b4e7692d00be221d (patch)
treecc350f046b53f6cf2ff4b9e0e6161acabf0b2ea3 /src/include/runtime/interface.h
parent94f81c534bdddb2f0530bbb799072599963e17fe (diff)
downloadtalos-hostboot-90ba110f5fda85e77cee73d8b4e7692d00be221d.tar.gz
talos-hostboot-90ba110f5fda85e77cee73d8b4e7692d00be221d.zip
HBRT interface contract clarifications
Change-Id: Ie07ec2cb2c3a0583f33600915804307fc71d87df Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/10668 Tested-by: Jenkins Server Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include/runtime/interface.h')
-rw-r--r--src/include/runtime/interface.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/include/runtime/interface.h b/src/include/runtime/interface.h
index f45f58b21..3178619f4 100644
--- a/src/include/runtime/interface.h
+++ b/src/include/runtime/interface.h
@@ -171,33 +171,35 @@ typedef struct runtimeInterfaces
* @param[in] i_common_addr_phys - The physical mainstore address of the
* OCC common area.
* @param[in] i_common_addr_va - Virtual memory address of the common area
- * @param[in] i_proc_chip - The processor chip id
+ * @param[in] i_chip - XSCOM chip id of processor based on devtree defn
* @return 0 on success else return code
*/
int(*loadOCC)(uint64_t i_homer_addr_phys,
uint64_t i_homer_addr_va,
uint64_t i_common_addr_phys,
uint64_t i_common_addr_va,
- uint64_t i_proc_chip);
+ uint64_t i_chip);
/** Start OCC on all chips, by module
*
* @param[in] i_proc_chip - Array of functional processor chip ids
* @Note The caller must include a complete modules worth of chips
* @param[in] i_num_chips - Number of chips in the array
* @return 0 on success else return code
*/
- int (*startOCCs)(uint64_t* i_proc_chip,
+ int (*startOCCs)(uint64_t* i_chip,
size_t i_num_chips);
/** Stop OCC hold OCCs in reset
*
* @param[in] i_proc_chip - Array of functional processor chip ids
* @Note The caller must include a complete modules worth of chips
* @param[in] i_num_chips - Number of chips in the array
* @return 0 on success else return code
*/
- int (*stopOCCs)(uint64_t* i_proc_chip,
+ int (*stopOCCs)(uint64_t* i_chip,
size_t i_num_chips);
OpenPOWER on IntegriCloud
@@ -171,33 +171,35 @@ typedef struct runtimeInterfaces
/** Start OCC on all chips, by module
*
- * @param[in] i_proc_chip - Array of functional processor chip ids
+ * @param[in] i_chip - Array of functional processor chip ids
+ * XSCOM chip id based on devtree defn
* @Note The caller must include a complete modules worth of chips
* @param[in] i_num_chips - Number of chips in the array
@@ -171,33 +171,35 @@ typedef struct runtimeInterfaces
/** Stop OCC hold OCCs in reset
*
- * @param[in] i_proc_chip - Array of functional processor chip ids
+ * @param[in] i_chip - Array of functional processor chip ids
+ * XSCOM chip id based on devtree defn
* @Note The caller must include a complete modules worth of chips
* @param[in] i_num_chips - Number of chips in the array